# coding: utf-8

from ruamel_yaml.compat import _F

# Abstract classes.

if False:  # MYPY
    from typing import Any, Dict, Optional, List  # NOQA

SHOW_LINES = False


def CommentCheck():
    # type: () -> None
    pass


class Event:
    __slots__ = 'start_mark', 'end_mark', 'comment'

    def __init__(self, start_mark=None, end_mark=None, comment=CommentCheck):
        # type: (Any, Any, Any) -> None
        self.start_mark = start_mark
        self.end_mark = end_mark
        # assert comment is not CommentCheck
        if comment is CommentCheck:
            comment = None
        self.comment = comment

    def __repr__(self):
        # type: () -> Any
        if True:
            arguments = []
            if hasattr(self, 'value'):
                # if you use repr(getattr(self, 'value')) then flake8 complains about
                # abuse of getattr with a constant. When you change to self.value
                # then mypy throws an error
                arguments.append(repr(self.value))  # type: ignore
            for key in ['anchor', 'tag', 'implicit', 'flow_style', 'style']:
                v = getattr(self, key, None)
                if v is not None:
                    arguments.append(_F('{key!s}={v!r}', key=key, v=v))
            if self.comment not in [None, CommentCheck]:
                arguments.append('comment={!r}'.format(self.comment))
            if SHOW_LINES:
                arguments.append(
                    '({}:{}/{}:{})'.format(
                        self.start_mark.line,
                        self.start_mark.column,
                        self.end_mark.line,
                        self.end_mark.column,
                    )
                )
            arguments = ', '.join(arguments)  # type: ignore
        else:
            attributes = [
                key
                for key in ['anchor', 'tag', 'implicit', 'value', 'flow_style', 'style']
                if hasattr(self, key)
            ]
            arguments = ', '.join(
                [_F('{k!s}={attr!r}', k=key, attr=getattr(self, key)) for key in attributes]
            )
            if self.comment not in [None, CommentCheck]:
                arguments += ', comment={!r}'.format(self.comment)
        return _F(
            '{self_class_name!s}({arguments!s})',
            self_class_name=self.__class__.__name__,
            arguments=arguments,
        )


class NodeEvent(Event):
    __slots__ = ('anchor',)

    def __init__(self, anchor, start_mark=None, end_mark=None, comment=None):
        # type: (Any, Any, Any, Any) -> None
        Event.__init__(self, start_mark, end_mark, comment)
        self.anchor = anchor


class CollectionStartEvent(NodeEvent):
    __slots__ = 'tag', 'implicit', 'flow_style', 'nr_items'

    def __init__(
        self,
        anchor,
        tag,
        implicit,
        start_mark=None,
        end_mark=None,
        flow_style=None,
        comment=None,
        nr_items=None,
    ):
        # type: (Any, Any, Any, Any, Any, Any, Any, Optional[int]) -> None
        NodeEvent.__init__(self, anchor, start_mark, end_mark, comment)
        self.tag = tag
        self.implicit = implicit
        self.flow_style = flow_style
        self.nr_items = nr_items


class CollectionEndEvent(Event):
    __slots__ = ()


# Implementations.


class StreamStartEvent(Event):
    __slots__ = ('encoding',)

    def __init__(self, start_mark=None, end_mark=None, encoding=None, comment=None):
        # type: (Any, Any, Any, Any) -> None
        Event.__init__(self, start_mark, end_mark, comment)
        self.encoding = encoding


class StreamEndEvent(Event):
    __slots__ = ()


class DocumentStartEvent(Event):
    __slots__ = 'explicit', 'version', 'tags'

    def __init__(
        self,
        start_mark=None,
        end_mark=None,
        explicit=None,
        version=None,
        tags=None,
        comment=None,
    ):
        # type: (Any, Any, Any, Any, Any, Any) -> None
        Event.__init__(self, start_mark, end_mark, comment)
        self.explicit = explicit
        self.version = version
        self.tags = tags


class DocumentEndEvent(Event):
    __slots__ = ('explicit',)

    def __init__(self, start_mark=None, end_mark=None, explicit=None, comment=None):
        # type: (Any, Any, Any, Any) -> None
        Event.__init__(self, start_mark, end_mark, comment)
        self.explicit = explicit


class AliasEvent(NodeEvent):
    __slots__ = 'style'

    def __init__(self, anchor, start_mark=None, end_mark=None, style=None, comment=None):
        # type: (Any, Any, Any, Any, Any) -> None
        NodeEvent.__init__(self, anchor, start_mark, end_mark, comment)
        self.style = style


class ScalarEvent(NodeEvent):
    __slots__ = 'tag', 'implicit', 'value', 'style'

    def __init__(
        self,
        anchor,
        tag,
        implicit,
        value,
        start_mark=None,
        end_mark=None,
        style=None,
        comment=None,
    ):
        # type: (Any, Any, Any, Any, Any, Any, Any, Any) -> None
        NodeEvent.__init__(self, anchor, start_mark, end_mark, comment)
        self.tag = tag
        self.implicit = implicit
        self.value = value
        self.style = style


class SequenceStartEvent(CollectionStartEvent):
    __slots__ = ()


class SequenceEndEvent(CollectionEndEvent):
    __slots__ = ()


class MappingStartEvent(CollectionStartEvent):
    __slots__ = ()


class MappingEndEvent(CollectionEndEvent):
    __slots__ = ()



import os
import ruamel_yaml


try:
    import pytest
except ImportError:
    pytest = None

if pytest:
    print('ruamel_yaml.__version__: %s' % ruamel_yaml.__version__)

# version_info is used in the package
# check that it exists and matches __version__
from ruamel_yaml import version_info
ver_string = '.'.join([str(i) for i in version_info])
print(f"The ruamel_yaml version info: {ver_string}")
assert ver_string == ruamel_yaml.__version__


def pip_show():
    cmd = 'if pip show ruamel.yaml; then exit 1; fi'
    # The result will be in stdout: 'WARNING: Package(s) not found: ruamel.yaml'
    # if ruamel.yaml is not installed in the test environment
    os.system(cmd)
    print("Checked `if pip show ruamel.yaml; then exit 1; fi`")
    return

def pip_install_ruamel_dot_yaml():
    try:
        cmd = "pip install ruamel.yaml"
        os.system(cmd)
        print("Checked `pip install ruamel.yaml`")
        return
    except Exception as e:
        print(e)

def import_ruamel_dot_yaml():
    try:
        cmd = "python -c 'import ruamel.yaml'"
        os.system(cmd)
        print("Checked `python -c 'import ruamel.yaml'`")
        return
    except ImportError as e:
        print(e)
    
def pip_check():
    cmd = "pip check"
    os.system(cmd)
    print("Checked `pip check`")
    return


if __name__ == "__main__":
    if os.name != "nt":
        pip_show()
        pip_install_ruamel_dot_yaml()
        import_ruamel_dot_yaml()

    pip_check()
